require(rKIN)
require(tidyverse)

# Get the Kest3 and Kest3 crossvalidation subset data
kest3<- read.table("Model3.csv", header = TRUE, sep = ",", stringsAsFactors = FALSE)
kestSub<- read.table(file = "InputDataForSampleSizeEffects.txt", header = TRUE, sep = "\t")

levels<- c(50, 75, 95) #confidence levels
# A vector of kernel bandwidth methods
bw<- c("hns", "hpi", "hscv", "hlscv", "hbcv", "hnm", "hucv", "ref")
# List of unique boot
boot<- unique(kestSub$Boot)
# List of unique subsamples
samp<- unique(kestSub$Subset)
# Create an output df
outBWOlap<- data.frame()
outBWArea<- data.frame()
outFail<- data.frame()
# Loop through the vectors and fit estimates
for(i in 1:length(samp)){
  for(j in 1:length(boot)){
    # Filter for the input points to be estimated
    s<- filter(.data = kestSub, Boot == boot[j] & Subset == samp[i])
    # Now loop through the kernel bw methods
    for(k in 1:length(bw)){
      kin<- try(estKIN(data = s, x = "d13C", y = "d15N", levels = levels, group = "Habitat", h = bw[k]), silent = TRUE)
      # Calc the overlap
      # oKin<- calcOverlap(kin)
      if(!inherits(kin, "try-error")){
        # Store the output
        outBWOlap<- rbind(outBWOlap, data.frame(Boot = boot[j], Subset = samp[i], Method = "Kernel", BW = bw[k], calcOverlap(kin)))
        outBWArea<- rbind(outBWArea, data.frame(Boot = j, Subset = samp[i], Method = "Kernel", BW = bw[k], getArea(kin)))
      } else{
        outFail<- rbind(outFail, data.frame(Boot = j, Subset = samp[i], Method = "Kernel", BW = bw[k]))
      }
      
    }
  }
}# close i


# Now let's summarize the results
sumArea<- summarise(group_by(.data = outBWArea, Subset, Method, BW, Group, ConfInt),
                    MeanArea = mean(ShapeArea, na.rm = TRUE),
                    SDArea = sd(ShapeArea, na.rm = TRUE),
                    N = length(na.omit(ShapeArea)),
                    CI95 = (sd(ShapeArea, na.rm = TRUE) / sqrt(length(na.omit(ShapeArea)))) * 1.96)

vertOlap<- gather(data = outBWOlap, key = "olapPair", "Overlap", 6:ncol(outBWOlap))
vertOlap$OverlapID<- as.character(vertOlap$OverlapID)
# Create some new columns to help us filter for only the data we want
vertOlap<- mutate(.data = vertOlap,
                  Hab1 = sapply(strsplit(OverlapID, "_"), "[", 1),
                  Pct1 = sapply(strsplit(OverlapID, "_"), "[", 2),
                  Hab2 = sapply(strsplit(olapPair, "_"), "[", 1),
                  Pct2 = sapply(strsplit(olapPair, "_"), "[", 2))

vertOlap<- mutate(.data = vertOlap, HabCombo = paste(Hab1, Hab2, sep = "_"))
# Now filter out the unneccesary rows
vertOlap <- filter(.data = vertOlap, OverlapID != olapPair & Hab1 != Hab2 & Pct1 == Pct2)

# Calculate the average values
sumOlap<- summarise(group_by(.data = vertOlap, Subset, Method, BW, HabCombo, Pct1),
                    MeanOverlap = mean(Overlap, na.rm = TRUE),
                    SDOverlap = sd(Overlap, na.rm = TRUE),
                    N = length(na.omit(Overlap)),
                    CI95 = (sd(Overlap, na.rm = TRUE) / sqrt(length(na.omit(Overlap)))) * 1.96)


sumOlap$HabCombo<- as.factor(sumOlap$HabCombo)
sumOlap<- mutate(.data = sumOlap, MethHab =  paste(Method, HabCombo, sep = "_"))

ggplot(data = filter(.data = sumOlap, Pct1 == "50" & Method == "Kernel"), aes(x = Subset, y = MeanOverlap, group = MethHab, color = MethHab)) +
  geom_line() +
  geom_errorbar(aes(ymin = MeanOverlap - CI95, ymax = MeanOverlap + CI95, width = 0.1))


# write out the two datasets
write.table(sumOlap, file = "BandwidthTypeEffects_OverlapByHabitatMethod.txt", sep = "\t", row.names = FALSE)
write.table(sumArea, file = "BandwidthTypeEffects_AreaByHabitatMethod.txt", sep = "\t", row.names = FALSE)

plotKIN(kin, alpha = .3)
