require(rKIN)
require(tidyverse)
# ////////////////////////////////////////////
# Kestrel data
kest3<- read.table("Model3.csv", header = TRUE, sep = ",", stringsAsFactors = FALSE)

# Sample subset vector
rnd<- c(12, 15, 17)
boot<- 10
levels<- c(50, 75, 95) #confidence levels

# Store the output
outOlap<- data.frame()
outArea<- data.frame()
outPts<- data.frame()
for(i in 1:length(rnd)){
  for(j in 1:boot){
    # Grab the stratified random sample
    rsamp<- data.frame(kest3 %>% group_by(Habitat) %>% sample_n(rnd[i], replace = FALSE))
    # Store the pts so we can repeat for the publication data
    outPts<- rbind(outPts, data.frame(Boot = j, Subset = rnd[i], rsamp))
    # Make the estimates for Forest
    kin<- estKIN(data = rsamp, x="d13C", y="d15N", levels=levels, group="Habitat", h = "ref")
    mc<- estMCP(data = rsamp, x="d13C", y="d15N", levels=levels, group="Habitat")
    el<- estEllipse(data = rsamp, x="d13C", y="d15N", levels=levels, group="Habitat")
    # Get the overlap of habitats
    # oKin<- calcOverlap(kin)
    # oMc<- calcOverlap(mc)
    # oEl<- calcOverlap(el)
    outOlap<- rbind(outOlap, data.frame(Boot = j, Subset = rnd[i], Method = "Kernel", calcOverlap(kin)),
                    data.frame(Boot = j, Subset = rnd[i], Method = "MCP", calcOverlap(mc)),
                    data.frame(Boot = j, Subset = rnd[i], Method = "Ellipse", calcOverlap(el)))
    outArea<- rbind(outArea, data.frame(Boot = j, Subset = rnd[i], getArea(kin)), data.frame(Boot = j, Subset = rnd[i], getArea(mc)))
  }
}


# Now let's summarize the results
sumArea<- summarise(group_by(.data = outArea, Subset, Method, Group, ConfInt),
                    MeanArea = mean(ShapeArea, na.rm = TRUE),
                    SDArea = sd(ShapeArea, na.rm = TRUE),
                    N = length(na.omit(ShapeArea)),
                    CI95 = (sd(ShapeArea, na.rm = TRUE) / sqrt(length(na.omit(ShapeArea)))) * 1.96)

vertOlap<- gather(data = outOlap, key = "olapPair", "Overlap", 5:ncol(outOlap))
vertOlap$OverlapID<- as.character(vertOlap$OverlapID)
# Create some new columns to help us filter for only the data we want
vertOlap<- mutate(.data = vertOlap,
                  Hab1 = sapply(strsplit(OverlapID, "_"), "[", 1),
                  Pct1 = sapply(strsplit(OverlapID, "_"), "[", 2),
                  Hab2 = sapply(strsplit(olapPair, "_"), "[", 1),
                  Pct2 = sapply(strsplit(olapPair, "_"), "[", 2))

vertOlap<- mutate(.data = vertOlap, HabCombo = paste(Hab1, Hab2, sep = "_"))
# Now filter out the unneccesary rows
vertOlap <- filter(.data = vertOlap, OverlapID != olapPair & Hab1 != Hab2 & Pct1 == Pct2)

# Calculate the average values
sumOlap<- summarise(group_by(.data = vertOlap, Subset, Method, HabCombo, Pct1),
                    MeanOverlap = mean(Overlap, na.rm = TRUE),
                    SDOverlap = sd(Overlap, na.rm = TRUE),
                    N = length(na.omit(Overlap)),
                    CI95 = (sd(Overlap, na.rm = TRUE) / sqrt(length(na.omit(Overlap)))) * 1.96)
sumOlap$HabCombo<- as.factor(sumOlap$HabCombo)
sumOlap<- mutate(.data = sumOlap, MethHab =  paste(Method, HabCombo, sep = "_"))

ggplot(data = filter(.data = sumOlap, Pct1 == "50" & Method == "Kernel"), aes(x = Subset, y = MeanOverlap, group = MethHab, color = MethHab)) +
  geom_line() +
  geom_errorbar(aes(ymin = MeanOverlap - CI95, ymax = MeanOverlap + CI95, width = 0.1))


# write out the two datasets
write.table(sumOlap, file = "SampleSizeEffects_OverlapByHabitatMethod_NewSamples.txt", sep = "\t", row.names = FALSE)
write.table(sumArea, file = "SampleSizeEffects_AreaByHabitatMethod_NewSamples.txt", sep = "\t", row.names = FALSE)
write.table(outPts, file = "InputDataForSampleSizeEffects.txt", sep = "\t", row.names = FALSE)

kOlap<- sumOlap %>%
  filter(Method == "Kernel")

mOlap<- kOlap %>%
  select(Subset, Method, HabCombo, Pct1, MeanOverlap) %>%
  spread(key = HabCombo, value = MeanOverlap)
names(mOlap)[4:9]<- paste("Mean", names(mOlap)[4:9], sep = "_")

cOlap<- kOlap %>%
  select(Subset, Method, HabCombo, Pct1, CI95) %>%
  spread(key = HabCombo, value = CI95)
names(cOlap)[4:9]<- paste("CI95", names(cOlap)[4:9], sep = "_")

kOlap<- mOlap %>%
  left_join(cOlap, by = c("Subset", "Method", "Pct1"))

write.table(kOlap, file = "SampleSizeEffects_OverlapByHabitatMethod_KernelOnly.txt", sep = "\t", row.names = FALSE)


kArea<- sumArea %>%
  filter(Method == "Kernel")

mArea<- kArea %>%
  select(Subset, Method, Group, ConfInt, MeanArea) %>%
  spread(key = Group, value = MeanArea)
names(mArea)[4:6]<- paste("Mean", names(mArea)[4:6], sep = "_")

cArea<- kArea %>%
  select(Subset, Method, Group, ConfInt, CI95) %>%
  spread(key = Group, value = CI95)
names(cArea)[4:6]<- paste("CI95", names(cArea)[4:6], sep = "_")

kArea<- mArea %>%
  left_join(cArea, by = c("Subset", "Method", "ConfInt"))

write.table(kArea, file = "SampleSizeEffects_AreaByHabitatMethod_KernelOnly.txt", sep = "\t", row.names = FALSE)
# %>%
#   select(Subset, Method, HabCombo, Pct1, MeanOverlap) %>%
#   spread(key = HabCombo, value = MeanOverlap)




